@@ -26,6 +26,13 @@ def set_token_parser(parent_parser: 'ArgumentParser' = None):
         help='Validity period (days)',
     )
 
+    create_parser.add_argument(
+        '--format',
+        type=str,
+        default='table',
+        help='Display format of the token, one of [table, raw]',
+    )
+
     create_parser.add_argument(
         'name',
         type=str,
