@@ -8,6 +8,14 @@ PROTOCOL = 'rpc'
 VERSION = 'v2'
 
 
+def get_domain_url():
+    domain = DOMAIN
+    if 'JINA_HUBBLE_REGISTRY' in os.environ:
+        domain = os.environ['JINA_HUBBLE_REGISTRY']
+
+    return f'{domain}/'
+
+
 def get_base_url():
     """Get the base url based on environment"""
 
